Crate multiarch_hints

Crate multiarch_hints 

Structs

ApplyMultiarchHintsConfig
Configuration options for applying multiarch hints
Change
Hint
OverallResult

Enums

Certainty
Re-export so library consumers (e.g. an LSP host) don’t have to add a direct debian-analyzer dep just to spell the certainty parameter to detect_multiarch_hints. Certainty of a change.
HintKind
OverallError
Severity

Constants

MULTIARCH_HINTS_URL

Functions

apply_multiarch_hints
cache_dir
Locate the directory we cache the downloaded multiarch-hints file in.
cache_download_multiarch_hints
cache_file_path
Path to the cached multiarch-hints file, or None when no cache directory is available. The directory is not created here — the sync/async cache wrappers call their respective create_dir_all before writing.
calculate_value
detect_multiarch_hints
Detect which multiarch hints apply to the given workspace.
download_multiarch_hints
multiarch_hints_by_binary
multiarch_hints_by_source
parse_multiarch_hints